@@ -1,13 +1,15 @@
-#' Add point coordinates to table
+#' @title Add point coordinates to table
 #'
-#' Modifies the attribute table of a point vector by adding fields containing each point's X and Y coordinates.
+#' @description Modifies the attribute table of a point vector by adding fields containing each point's X and Y coordinates.
 #'
 #' @param input Input vector Points file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_add_point_coordinates_to_table <- function(input, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -25,17 +27,19 @@ wbt_add_point_coordinates_to_table <- function(input, wd=NULL, verbose_mode=FALS
 }
 
 
-#' Clean vector
+#' @title Clean vector
 #'
-#' Removes null features and lines/polygons with fewer than the required number of vertices.
+#' @description Removes null features and lines/polygons with fewer than the required number of vertices.
 #'
 #' @param input Input vector file.
 #' @param output Output vector file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_clean_vector <- function(input, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -54,17 +58,19 @@ wbt_clean_vector <- function(input, output, wd=NULL, verbose_mode=FALSE, compres
 }
 
 
-#' Convert nodata to zero
+#' @title Convert nodata to zero
 #'
-#' Converts nodata values in a raster to zero.
+#' @description Converts nodata values in a raster to zero.
 #'
 #' @param input Input raster file.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_convert_nodata_to_zero <- function(input, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -83,17 +89,19 @@ wbt_convert_nodata_to_zero <- function(input, output, wd=NULL, verbose_mode=FALS
 }
 
 
-#' Convert raster format
+#' @title Convert raster format
 #'
-#' Converts raster data from one format to another.
+#' @description Converts raster data from one format to another.
 #'
 #' @param input Input raster file.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_convert_raster_format <- function(input, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -112,9 +120,9 @@ wbt_convert_raster_format <- function(input, output, wd=NULL, verbose_mode=FALSE
 }
 
 
-#' Csv points to vector
+#' @title Csv points to vector
 #'
-#' Converts a CSV text file to vector points.
+#' @description Converts a CSV text file to vector points.
 #'
 #' @param input Input CSV file (i.e. source of data to be imported).
 #' @param output Output vector file.
@@ -123,9 +131,11 @@ wbt_convert_raster_format <- function(input, output, wd=NULL, verbose_mode=FALSE
 #' @param epsg EPSG projection (e.g. 2958).
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_csv_points_to_vector <- function(input, output, xfield=0, yfield=1, epsg=NULL, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -153,18 +163,20 @@ wbt_csv_points_to_vector <- function(input, output, xfield=0, yfield=1, epsg=NUL
 }
 
 
-#' Export table to csv
+#' @title Export table to csv
 #'
-#' Exports an attribute table to a CSV text file.
+#' @description Exports an attribute table to a CSV text file.
 #'
 #' @param input Input vector file.
 #' @param output Output csv file.
 #' @param headers Export field names as file header?.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_export_table_to_csv <- function(input, output, headers=TRUE, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -186,18 +198,20 @@ wbt_export_table_to_csv <- function(input, output, headers=TRUE, wd=NULL, verbos
 }
 
 
-#' Fix dangling arcs
+#' @title Fix dangling arcs
 #'
-#' This tool fixes undershot and overshot arcs, two common topological errors, in an input vector lines file.
+#' @description This tool fixes undershot and overshot arcs, two common topological errors, in an input vector lines file.
 #'
 #' @param input Name of the input lines vector file.
 #' @param output Name of the output lines vector file.
 #' @param dist Snap distance, in xy units (metres).
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_fix_dangling_arcs <- function(input, output, dist="", wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -219,9 +233,9 @@ wbt_fix_dangling_arcs <- function(input, output, dist="", wd=NULL, verbose_mode=
 }
 
 
-#' Join tables
+#' @title Join tables
 #'
-#' Merge a vector's attribute table with another table based on a common field.
+#' @description Merge a vector's attribute table with another table based on a common field.
 #'
 #' @param input1 Input primary vector file (i.e. the table to be modified).
 #' @param pkey Primary key field.
@@ -230,9 +244,11 @@ wbt_fix_dangling_arcs <- function(input, output, dist="", wd=NULL, verbose_mode=
 #' @param import_field Imported field (all fields will be imported if not specified).
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_join_tables <- function(input1, pkey, input2, fkey, import_field=NULL, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -256,17 +272,19 @@ wbt_join_tables <- function(input1, pkey, input2, fkey, import_field=NULL, wd=NU
 }
 
 
-#' Lines to polygons
+#' @title Lines to polygons
 #'
-#' Converts vector polylines to polygons.
+#' @description Converts vector polylines to polygons.
 #'
 #' @param input Input vector line file.
 #' @param output Output vector polygon file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_lines_to_polygons <- function(input, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -285,9 +303,9 @@ wbt_lines_to_polygons <- function(input, output, wd=NULL, verbose_mode=FALSE, co
 }
 
 
-#' Merge table with csv
+#' @title Merge table with csv
 #'
-#' Merge a vector's attribute table with a table contained within a CSV text file.
+#' @description Merge a vector's attribute table with a table contained within a CSV text file.
 #'
 #' @param input Input primary vector file (i.e. the table to be modified).
 #' @param pkey Primary key field.
@@ -296,9 +314,11 @@ wbt_lines_to_polygons <- function(input, output, wd=NULL, verbose_mode=FALSE, co
 #' @param import_field Imported field (all fields will be imported if not specified).
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_merge_table_with_csv <- function(input, pkey, csv, fkey, import_field=NULL, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -322,17 +342,19 @@ wbt_merge_table_with_csv <- function(input, pkey, csv, fkey, import_field=NULL,
 }
 
 
-#' Merge vectors
+#' @title Merge vectors
 #'
-#' Combines two or more input vectors of the same ShapeType creating a single, new output vector.
+#' @description Combines two or more input vectors of the same ShapeType creating a single, new output vector.
 #'
 #' @param inputs Input vector files.
 #' @param output Output vector file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_merge_vectors <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -351,17 +373,19 @@ wbt_merge_vectors <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compr
 }
 
 
-#' Modify no data value
+#' @title Modify no data value
 #'
-#' Converts nodata values in a raster to zero.
+#' @description Modifies nodata values in a raster.
 #'
 #' @param input Input raster file.
 #' @param new_value New NoData value.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_modify_no_data_value <- function(input, new_value="-32768.0", wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -382,18 +406,20 @@ wbt_modify_no_data_value <- function(input, new_value="-32768.0", wd=NULL, verbo
 }
 
 
-#' Multi part to single part
+#' @title Multi part to single part
 #'
-#' Converts a vector file containing multi-part features into a vector containing only single-part features.
+#' @description Converts a vector file containing multi-part features into a vector containing only single-part features.
 #'
 #' @param input Input vector line or polygon file.
 #' @param output Output vector line or polygon file.
 #' @param exclude_holes Exclude hole parts from the feature splitting? (holes will continue to belong to their features in output.).
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_multi_part_to_single_part <- function(input, output, exclude_holes=TRUE, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -415,9 +441,9 @@ wbt_multi_part_to_single_part <- function(input, output, exclude_holes=TRUE, wd=
 }
 
 
-#' New raster from base
+#' @title New raster from base
 #'
-#' Creates a new raster using a base image.
+#' @description Creates a new raster using a base image.
 #'
 #' @param base Input base raster file.
 #' @param output Output raster file.
@@ -426,9 +452,11 @@ wbt_multi_part_to_single_part <- function(input, output, exclude_holes=TRUE, wd=
 #' @param cell_size Optionally specified cell size of output raster. Not used when base raster is specified.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_new_raster_from_base <- function(base, output, value="nodata", data_type="float", cell_size=NULL, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -456,17 +484,19 @@ wbt_new_raster_from_base <- function(base, output, value="nodata", data_type="fl
 }
 
 
-#' Polygons to lines
+#' @title Polygons to lines
 #'
-#' Converts vector polygons to polylines.
+#' @description Converts vector polygons to polylines.
 #'
 #' @param input Input vector polygon file.
 #' @param output Output vector lines file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_polygons_to_lines <- function(input, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -485,16 +515,18 @@ wbt_polygons_to_lines <- function(input, output, wd=NULL, verbose_mode=FALSE, co
 }
 
 
-#' Print geo tiff tags
+#' @title Print geo tiff tags
 #'
-#' Prints the tags within a GeoTIFF.
+#' @description Prints the tags within a GeoTIFF.
 #'
 #' @param input Input GeoTIFF file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_print_geo_tiff_tags <- function(input, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -512,17 +544,19 @@ wbt_print_geo_tiff_tags <- function(input, wd=NULL, verbose_mode=FALSE, compress
 }
 
 
-#' Raster to vector lines
+#' @title Raster to vector lines
 #'
-#' Converts a raster lines features into a vector of the POLYLINE shapetype.
+#' @description Converts a raster lines features into a vector of the POLYLINE shapetype.
 #'
 #' @param input Input raster lines file.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_raster_to_vector_lines <- function(input, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -541,17 +575,19 @@ wbt_raster_to_vector_lines <- function(input, output, wd=NULL, verbose_mode=FALS
 }
 
 
-#' Raster to vector points
+#' @title Raster to vector points
 #'
-#' Converts a raster dataset to a vector of the POINT shapetype.
+#' @description Converts a raster dataset to a vector of the POINT shapetype.
 #'
 #' @param input Input raster file.
 #' @param output Output vector points file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_raster_to_vector_points <- function(input, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -570,17 +606,19 @@ wbt_raster_to_vector_points <- function(input, output, wd=NULL, verbose_mode=FAL
 }
 
 
-#' Raster to vector polygons
+#' @title Raster to vector polygons
 #'
-#' Converts a raster dataset to a vector of the POLYGON shapetype.
+#' @description Converts a raster dataset to a vector of the POLYGON shapetype.
 #'
 #' @param input Input raster file.
 #' @param output Output vector polygons file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_raster_to_vector_polygons <- function(input, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -599,16 +637,18 @@ wbt_raster_to_vector_polygons <- function(input, output, wd=NULL, verbose_mode=F
 }
 
 
-#' Reinitialize attribute table
+#' @title Reinitialize attribute table
 #'
-#' Reinitializes a vector's attribute table deleting all fields but the feature ID (FID).
+#' @description Reinitializes a vector's attribute table deleting all fields but the feature ID (FID).
 #'
 #' @param input Input vector file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_reinitialize_attribute_table <- function(input, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -626,17 +666,19 @@ wbt_reinitialize_attribute_table <- function(input, wd=NULL, verbose_mode=FALSE,
 }
 
 
-#' Remove polygon holes
+#' @title Remove polygon holes
 #'
-#' Removes holes within the features of a vector polygon file.
+#' @description Removes holes within the features of a vector polygon file.
 #'
 #' @param input Input vector polygon file.
 #' @param output Output vector polygon file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_remove_polygon_holes <- function(input, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -655,18 +697,59 @@ wbt_remove_polygon_holes <- function(input, output, wd=NULL, verbose_mode=FALSE,
 }
 
 
-#' Set nodata value
+#' @title Remove raster polygon holes
 #'
-#' Assign a specified value in an input image to the NoData value.
+#' @description Removes polygon holes, or 'donut-holes', from raster polygons.
+#'
+#' @param input Name of the input raster image file.
+#' @param output Name of the output raster file.
+#' @param threshold Maximum size of removed holes, in grid cells. Blank for no threshold, i.e. remove all holes.
+#' @param use_diagonals Use diagonal neighbours during clumping operation.
+#' @param wd Changes the working directory.
+#' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
+#' @param command_only Return command that would be executed by `system()` rather than running tool.
+#'
+#' @keywords DataTools
+#'
+#' @return Returns the tool text outputs.
+#' @export
+wbt_remove_raster_polygon_holes <- function(input, output, threshold=3, use_diagonals=TRUE, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
+  wbt_init()
+  args <- ""
+  args <- paste(args, paste0("--input=", wbt_file_path(input)))
+  args <- paste(args, paste0("--output=", wbt_file_path(output)))
+  if (!is.null(threshold)) {
+    args <- paste(args, paste0("--threshold=", threshold))
+  }
+  if (use_diagonals) {
+    args <- paste(args, "--use_diagonals")
+  }
+  if (!missing(wd)) {
+    args <- paste(args, paste0("--wd=", wbt_file_path(wd)))
+  }
+  if (!missing(compress_rasters)) {
+    args <- paste(args, paste0("--compress_rasters=", compress_rasters))
+  }
+  tool_name <- "remove_raster_polygon_holes"
+  wbt_run_tool(tool_name, args, verbose_mode, command_only)
+}
+
+
+#' @title Set nodata value
+#'
+#' @description Assign the NoData value for an input image.
 #'
 #' @param input Input raster file.
 #' @param output Output raster file.
 #' @param back_value Background value to set to nodata.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_set_nodata_value <- function(input, output, back_value=0.0, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -688,18 +771,20 @@ wbt_set_nodata_value <- function(input, output, back_value=0.0, wd=NULL, verbose
 }
 
 
-#' Single part to multi part
+#' @title Single part to multi part
 #'
-#' Converts a vector file containing multi-part features into a vector containing only single-part features.
+#' @description Converts a vector file containing multi-part features into a vector containing only single-part features.
 #'
 #' @param input Input vector line or polygon file.
 #' @param field Grouping ID field name in attribute table.
 #' @param output Output vector line or polygon file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_single_part_to_multi_part <- function(input, output, field=NULL, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -721,9 +806,9 @@ wbt_single_part_to_multi_part <- function(input, output, field=NULL, wd=NULL, ve
 }
 
 
-#' Vector lines to raster
+#' @title Vector lines to raster
 #'
-#' Converts a vector containing polylines into a raster.
+#' @description Converts a vector containing polylines into a raster.
 #'
 #' @param input Input vector lines file.
 #' @param field Input field name in attribute table.
@@ -733,9 +818,11 @@ wbt_single_part_to_multi_part <- function(input, output, field=NULL, wd=NULL, ve
 #' @param base Optionally specified input base raster file. Not used when a cell size is specified.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_vector_lines_to_raster <- function(input, output, field="FID", nodata=TRUE, cell_size=NULL, base=NULL, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -766,9 +853,9 @@ wbt_vector_lines_to_raster <- function(input, output, field="FID", nodata=TRUE,
 }
 
 
-#' Vector points to raster
+#' @title Vector points to raster
 #'
-#' Converts a vector containing points into a raster.
+#' @description Converts a vector containing points into a raster.
 #'
 #' @param input Input vector Points file.
 #' @param field Input field name in attribute table.
@@ -779,9 +866,11 @@ wbt_vector_lines_to_raster <- function(input, output, field="FID", nodata=TRUE,
 #' @param base Optionally specified input base raster file. Not used when a cell size is specified.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_vector_points_to_raster <- function(input, output, field="FID", assign="last", nodata=TRUE, cell_size=NULL, base=NULL, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -815,9 +904,9 @@ wbt_vector_points_to_raster <- function(input, output, field="FID", assign="last
 }
 
 
-#' Vector polygons to raster
+#' @title Vector polygons to raster
 #'
-#' Converts a vector containing polygons into a raster.
+#' @description Converts a vector containing polygons into a raster.
 #'
 #' @param input Input vector polygons file.
 #' @param field Input field name in attribute table.
@@ -827,9 +916,11 @@ wbt_vector_points_to_raster <- function(input, output, field="FID", assign="last
 #' @param base Optionally specified input base raster file. Not used when a cell size is specified.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords DataTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_vector_polygons_to_raster <- function(input, output, field="FID", nodata=TRUE, cell_size=NULL, base=NULL, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
