@@ -1,14 +1,16 @@
-#' Average overlay
+#' @title Average overlay
 #'
-#' Calculates the average for each grid cell from a group of raster images.
+#' @description Calculates the average for each grid cell from a group of raster images.
 #'
 #' @param inputs Input raster files.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_average_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -27,18 +29,20 @@ wbt_average_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, com
 }
 
 
-#' Clip
+#' @title Clip
 #'
-#' Extract all the features, or parts of features, that overlap with the features of the clip vector.
+#' @description Extract all the features, or parts of features, that overlap with the features of the clip vector.
 #'
 #' @param input Input vector file.
 #' @param clip Input clip polygon vector file.
 #' @param output Output vector file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_clip <- function(input, clip, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -58,9 +62,9 @@ wbt_clip <- function(input, clip, output, wd=NULL, verbose_mode=FALSE, compress_
 }
 
 
-#' Clip raster to polygon
+#' @title Clip raster to polygon
 #'
-#' Clips a raster to a vector polygon.
+#' @description Clips a raster to a vector polygon.
 #'
 #' @param input Input raster file.
 #' @param polygons Input vector polygons file.
@@ -68,12 +72,14 @@ wbt_clip <- function(input, clip, output, wd=NULL, verbose_mode=FALSE, compress_
 #' @param maintain_dimensions Maintain input raster dimensions?.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
-wbt_clip_raster_to_polygon <- function(input, polygons, output, maintain_dimensions=TRUE, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
+wbt_clip_raster_to_polygon <- function(input, polygons, output, maintain_dimensions=FALSE, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
   wbt_init()
   args <- ""
   args <- paste(args, paste0("--input=", wbt_file_path(input)))
@@ -93,18 +99,20 @@ wbt_clip_raster_to_polygon <- function(input, polygons, output, maintain_dimensi
 }
 
 
-#' Count if
+#' @title Count if
 #'
-#' Counts the number of occurrences of a specified value in a cell-stack of rasters.
+#' @description Counts the number of occurrences of a specified value in a cell-stack of rasters.
 #'
 #' @param inputs Input raster files.
 #' @param output Output raster file.
 #' @param value Search value (e.g. countif value = 5.0).
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_count_if <- function(inputs, output, value, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -124,18 +132,20 @@ wbt_count_if <- function(inputs, output, value, wd=NULL, verbose_mode=FALSE, com
 }
 
 
-#' Difference
+#' @title Difference
 #'
-#' Outputs the features that occur in one of the two vector inputs but not both, i.e. no overlapping features.
+#' @description Outputs the features that occur in one of the two vector inputs but not both, i.e. no overlapping features.
 #'
 #' @param input Input vector file.
 #' @param overlay Input overlay vector file.
 #' @param output Output vector file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_difference <- function(input, overlay, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -155,18 +165,20 @@ wbt_difference <- function(input, overlay, output, wd=NULL, verbose_mode=FALSE,
 }
 
 
-#' Erase
+#' @title Erase
 #'
-#' Removes all the features, or parts of features, that overlap with the features of the erase vector polygon.
+#' @description Removes all the features, or parts of features, that overlap with the features of the erase vector polygon.
 #'
 #' @param input Input vector file.
 #' @param erase Input erase polygon vector file.
 #' @param output Output vector file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_erase <- function(input, erase, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -186,18 +198,20 @@ wbt_erase <- function(input, erase, output, wd=NULL, verbose_mode=FALSE, compres
 }
 
 
-#' Erase polygon from raster
+#' @title Erase polygon from raster
 #'
-#' Erases (cuts out) a vector polygon from a raster.
+#' @description Erases (cuts out) a vector polygon from a raster.
 #'
 #' @param input Input raster file.
 #' @param polygons Input vector polygons file.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_erase_polygon_from_raster <- function(input, polygons, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -217,17 +231,19 @@ wbt_erase_polygon_from_raster <- function(input, polygons, output, wd=NULL, verb
 }
 
 
-#' Highest position
+#' @title Highest position
 #'
-#' Identifies the stack position of the maximum value within a raster stack on a cell-by-cell basis.
+#' @description Identifies the stack position of the maximum value within a raster stack on a cell-by-cell basis.
 #'
 #' @param inputs Input raster files.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_highest_position <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -246,9 +262,9 @@ wbt_highest_position <- function(inputs, output, wd=NULL, verbose_mode=FALSE, co
 }
 
 
-#' Intersect
+#' @title Intersect
 #'
-#' Identifies the parts of features in common between two input vector layers.
+#' @description Identifies the parts of features in common between two input vector layers.
 #'
 #' @param input Input vector file.
 #' @param overlay Input overlay vector file.
@@ -256,9 +272,11 @@ wbt_highest_position <- function(inputs, output, wd=NULL, verbose_mode=FALSE, co
 #' @param snap Snap tolerance.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_intersect <- function(input, overlay, output, snap=0.0, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -281,18 +299,20 @@ wbt_intersect <- function(input, overlay, output, snap=0.0, wd=NULL, verbose_mod
 }
 
 
-#' Line intersections
+#' @title Line intersections
 #'
-#' Identifies points where the features of two vector line layers intersect.
+#' @description Identifies points where the features of two vector line layers intersect.
 #'
 #' @param input1 Input vector polyline file.
 #' @param input2 Input vector polyline file.
 #' @param output Output vector point file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_line_intersections <- function(input1, input2, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -312,17 +332,19 @@ wbt_line_intersections <- function(input1, input2, output, wd=NULL, verbose_mode
 }
 
 
-#' Lowest position
+#' @title Lowest position
 #'
-#' Identifies the stack position of the minimum value within a raster stack on a cell-by-cell basis.
+#' @description Identifies the stack position of the minimum value within a raster stack on a cell-by-cell basis.
 #'
 #' @param inputs Input raster files.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_lowest_position <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -341,17 +363,19 @@ wbt_lowest_position <- function(inputs, output, wd=NULL, verbose_mode=FALSE, com
 }
 
 
-#' Max absolute overlay
+#' @title Max absolute overlay
 #'
-#' Evaluates the maximum absolute value for each grid cell from a stack of input rasters.
+#' @description Evaluates the maximum absolute value for each grid cell from a stack of input rasters.
 #'
 #' @param inputs Input raster files.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_max_absolute_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -370,17 +394,19 @@ wbt_max_absolute_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE
 }
 
 
-#' Max overlay
+#' @title Max overlay
 #'
-#' Evaluates the maximum value for each grid cell from a stack of input rasters.
+#' @description Evaluates the maximum value for each grid cell from a stack of input rasters.
 #'
 #' @param inputs Input raster files.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_max_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -399,18 +425,20 @@ wbt_max_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compres
 }
 
 
-#' Merge line segments
+#' @title Merge line segments
 #'
-#' Merges vector line segments into larger features.
+#' @description Merges vector line segments into larger features.
 #'
 #' @param input Input vector file.
 #' @param output Output vector file.
 #' @param snap Snap tolerance.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_merge_line_segments <- function(input, output, snap=0.0, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -432,17 +460,19 @@ wbt_merge_line_segments <- function(input, output, snap=0.0, wd=NULL, verbose_mo
 }
 
 
-#' Min absolute overlay
+#' @title Min absolute overlay
 #'
-#' Evaluates the minimum absolute value for each grid cell from a stack of input rasters.
+#' @description Evaluates the minimum absolute value for each grid cell from a stack of input rasters.
 #'
 #' @param inputs Input raster files.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_min_absolute_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -461,17 +491,19 @@ wbt_min_absolute_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE
 }
 
 
-#' Min overlay
+#' @title Min overlay
 #'
-#' Evaluates the minimum value for each grid cell from a stack of input rasters.
+#' @description Evaluates the minimum value for each grid cell from a stack of input rasters.
 #'
 #' @param inputs Input raster files.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_min_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -490,17 +522,19 @@ wbt_min_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compres
 }
 
 
-#' Multiply overlay
+#' @title Multiply overlay
 #'
-#' Calculates the sum for each grid cell from a group of raster images.
+#' @description Calculates the sum for each grid cell from a group of raster images.
 #'
 #' @param inputs Input raster files.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_multiply_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -519,18 +553,20 @@ wbt_multiply_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, co
 }
 
 
-#' Percent equal to
+#' @title Percent equal to
 #'
-#' Calculates the percentage of a raster stack that have cell values equal to an input on a cell-by-cell basis.
+#' @description Calculates the percentage of a raster stack that have cell values equal to an input on a cell-by-cell basis.
 #'
 #' @param inputs Input raster files.
 #' @param comparison Input comparison raster file.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_percent_equal_to <- function(inputs, comparison, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -550,18 +586,20 @@ wbt_percent_equal_to <- function(inputs, comparison, output, wd=NULL, verbose_mo
 }
 
 
-#' Percent greater than
+#' @title Percent greater than
 #'
-#' Calculates the percentage of a raster stack that have cell values greater than an input on a cell-by-cell basis.
+#' @description Calculates the percentage of a raster stack that have cell values greater than an input on a cell-by-cell basis.
 #'
 #' @param inputs Input raster files.
 #' @param comparison Input comparison raster file.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_percent_greater_than <- function(inputs, comparison, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -581,18 +619,20 @@ wbt_percent_greater_than <- function(inputs, comparison, output, wd=NULL, verbos
 }
 
 
-#' Percent less than
+#' @title Percent less than
 #'
-#' Calculates the percentage of a raster stack that have cell values less than an input on a cell-by-cell basis.
+#' @description Calculates the percentage of a raster stack that have cell values less than an input on a cell-by-cell basis.
 #'
 #' @param inputs Input raster files.
 #' @param comparison Input comparison raster file.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_percent_less_than <- function(inputs, comparison, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -612,18 +652,20 @@ wbt_percent_less_than <- function(inputs, comparison, output, wd=NULL, verbose_m
 }
 
 
-#' Pick from list
+#' @title Pick from list
 #'
-#' Outputs the value from a raster stack specified by a position raster.
+#' @description Outputs the value from a raster stack specified by a position raster.
 #'
 #' @param inputs Input raster files.
 #' @param pos_input Input position raster file.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_pick_from_list <- function(inputs, pos_input, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -643,17 +685,19 @@ wbt_pick_from_list <- function(inputs, pos_input, output, wd=NULL, verbose_mode=
 }
 
 
-#' Polygonize
+#' @title Polygonize
 #'
-#' Creates a polygon layer from two or more intersecting line features contained in one or more input vector line files.
+#' @description Creates a polygon layer from two or more intersecting line features contained in one or more input vector line files.
 #'
 #' @param inputs Input vector polyline file.
 #' @param output Output vector polygon file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_polygonize <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -672,18 +716,20 @@ wbt_polygonize <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compress
 }
 
 
-#' Split with lines
+#' @title Split with lines
 #'
-#' Splits the lines or polygons in one layer using the lines in another layer.
+#' @description Splits the lines or polygons in one layer using the lines in another layer.
 #'
 #' @param input Input vector line or polygon file.
 #' @param split Input vector polyline file.
 #' @param output Output vector file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_split_with_lines <- function(input, split, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -703,17 +749,19 @@ wbt_split_with_lines <- function(input, split, output, wd=NULL, verbose_mode=FAL
 }
 
 
-#' Sum overlay
+#' @title Sum overlay
 #'
-#' Calculates the sum for each grid cell from a group of raster images.
+#' @description Calculates the sum for each grid cell from a group of raster images.
 #'
 #' @param inputs Input raster files.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_sum_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -732,9 +780,9 @@ wbt_sum_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compres
 }
 
 
-#' Symmetrical difference
+#' @title Symmetrical difference
 #'
-#' Outputs the features that occur in one of the two vector inputs but not both, i.e. no overlapping features.
+#' @description Outputs the features that occur in one of the two vector inputs but not both, i.e. no overlapping features.
 #'
 #' @param input Input vector file.
 #' @param overlay Input overlay vector file.
@@ -742,9 +790,11 @@ wbt_sum_overlay <- function(inputs, output, wd=NULL, verbose_mode=FALSE, compres
 #' @param snap Snap tolerance.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_symmetrical_difference <- function(input, overlay, output, snap=0.0, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -767,9 +817,9 @@ wbt_symmetrical_difference <- function(input, overlay, output, snap=0.0, wd=NULL
 }
 
 
-#' Union
+#' @title Union
 #'
-#' Splits vector layers at their overlaps, creating a layer containing all the portions from both input and overlay layers.
+#' @description Splits vector layers at their overlaps, creating a layer containing all the portions from both input and overlay layers.
 #'
 #' @param input Input vector file.
 #' @param overlay Input overlay vector file.
@@ -777,9 +827,11 @@ wbt_symmetrical_difference <- function(input, overlay, output, snap=0.0, wd=NULL
 #' @param snap Snap tolerance.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_union <- function(input, overlay, output, snap=0.0, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -802,18 +854,20 @@ wbt_union <- function(input, overlay, output, snap=0.0, wd=NULL, verbose_mode=FA
 }
 
 
-#' Update nodata cells
+#' @title Update nodata cells
 #'
-#' Replaces the NoData values in an input raster with the corresponding values contained in a second update layer.
+#' @description Replaces the NoData values in an input raster with the corresponding values contained in a second update layer.
 #'
 #' @param input1 Input raster file 1.
 #' @param input2 Input raster file 2; update layer.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_update_nodata_cells <- function(input1, input2, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -833,9 +887,9 @@ wbt_update_nodata_cells <- function(input1, input2, output, wd=NULL, verbose_mod
 }
 
 
-#' Weighted overlay
+#' @title Weighted overlay
 #'
-#' Performs a weighted sum on multiple input rasters after converting each image to a common scale. The tool performs a multi-criteria evaluation (MCE).
+#' @description Performs a weighted sum on multiple input rasters after converting each image to a common scale. The tool performs a multi-criteria evaluation (MCE).
 #'
 #' @param factors Input factor raster files.
 #' @param weights Weight values, contained in quotes and separated by commas or semicolons. Must have the same number as factors.
@@ -845,9 +899,11 @@ wbt_update_nodata_cells <- function(input1, input2, output, wd=NULL, verbose_mod
 #' @param scale_max Suitability scale maximum value (common values are 1.0, 100.0, and 255.0).
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_weighted_overlay <- function(factors, weights, output, cost=NULL, constraints=NULL, scale_max=1.0, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
@@ -876,18 +932,20 @@ wbt_weighted_overlay <- function(factors, weights, output, cost=NULL, constraint
 }
 
 
-#' Weighted sum
+#' @title Weighted sum
 #'
-#' Performs a weighted-sum overlay on multiple input raster images.
+#' @description Performs a weighted-sum overlay on multiple input raster images.
 #'
 #' @param inputs Input raster files.
 #' @param weights Weight values, contained in quotes and separated by commas or semicolons.
 #' @param output Output raster file.
 #' @param wd Changes the working directory.
 #' @param verbose_mode Sets verbose mode. If verbose mode is `FALSE`, tools will not print output messages.
-#' @param compress_rasters Sets the flag used by WhiteboxTools to determine whether to use compression for output rasters.
+#' @param compress_rasters Sets the flag used by 'WhiteboxTools' to determine whether to use compression for output rasters.
 #' @param command_only Return command that would be executed by `system()` rather than running tool.
 #'
+#' @keywords GISAnalysisOverlayTools
+#'
 #' @return Returns the tool text outputs.
 #' @export
 wbt_weighted_sum <- function(inputs, weights, output, wd=NULL, verbose_mode=FALSE, compress_rasters=FALSE, command_only=FALSE) {
